<?php
require_once("dbconn.php");
require_once("phpFunctions.php");

$batchDetailsResult = executeQuery($conn, "SELECT BatchName, BldgNo FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE");

if ($batchDetailsResult === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$batchDetails = [];
if ($batchDetailsResult->num_rows > 0)
	{
    while($xrow = $batchDetailsResult->fetch_assoc()) 
	{
        $batchDetails[] = $xrow;
    }
}

$existingPRE1Query = "SELECT COUNT(*) FROM predata_ip WHERE ProductionDate = ?";
$existingPRE1Result = executeQuery($conn, $existingPRE1Query, "s", [date("Y-m-d")]);

if ($existingPRE1Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPRE1Count = mysqli_fetch_row($existingPRE1Result)[0];

$existingPOST1Query = "SELECT COUNT(*) FROM input_production WHERE ProductionDate = ?";
$existingPOST1Result = executeQuery($conn, $existingPOST1Query, "s", [date("Y-m-d")]);

if ($existingPOST1Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPOST1Count = mysqli_fetch_row($existingPOST1Result)[0];

mysqli_begin_transaction($conn);

$per_balance = 0;

if ($existingPRE1Count == 0 && $existingPOST1Count == 0) {
    try {
        foreach ($batchDetails as $detail) {
            $BatchName = $detail["BatchName"];
            $bldgNos = explode(",", $detail["BldgNo"]);
			
			$AgeResult = executeQuery($conn, "SELECT FLOOR(DATEDIFF(?, CheckInDate) / 7) as AgeInWeeks FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE AND BatchName = ?", "ss", [date("Y-m-d"),$BatchName]);
			
			if ($AgeResult === false) { 
				throw new Exception("Error executing query: " . $conn->error);
			} 
			
			$AgeRow = mysqli_fetch_assoc($AgeResult);
			$AgeInWeeks = $AgeRow["AgeInWeeks"];
			
            foreach ($bldgNos as $bldgNo) {
				preg_match('/\[(.*?)\]/', $bldgNo, $matches);
				$per_balance = $matches[1] ?? 0;
				
				$cleanedBldgNo = preg_replace('/\[\d+\]/', '', $bldgNo);
				$cleanedBldgNo = trim($cleanedBldgNo);
				
				$FCodeResult = executeQuery($conn, "SELECT FCode FROM fcode WHERE is_deleted = FALSE AND is_current = TRUE AND BatchName = ? AND BldgNo = ?", "ss", [$BatchName, $cleanedBldgNo]);
				
				if ($FCodeResult === false) { 
					throw new Exception("Error executing query: " . $conn->error);
				} 
				
				$FCodeRow = mysqli_fetch_assoc($FCodeResult);
				$FCode = $FCodeRow["FCode"] ?? "";

                $eggProdResult = executeQuery($conn, "INSERT INTO predata_ip (addedby_user, ProductionDate, BatchName, BldgNo, AgeInWeeks, Hen_Day, F_CODE) VALUES (?, ?, ?, ?, ?, ?, ?)", "sssssss", [$userName, date("Y-m-d"), $BatchName, $cleanedBldgNo, $AgeInWeeks, $per_balance, $FCode]);
				
				if ($eggProdResult === false) { 
					throw new Exception("Error executing query: " . $conn->error);
				} 
		   }
        }
        mysqli_commit($conn);
    } 
    catch (Exception $e) 
    {
        mysqli_rollback($conn);
		// Log the error message
        error_log($e->getMessage());
		// Redirect to an error page or display an error message
        //header("Location: error_page.php");
        //exit();
    }
}

$eggSizeResult = executeQuery($conn, "SELECT * FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE");

if ($eggSizeResult === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$eggSizeDetails = [];
if ($eggSizeResult->num_rows > 0)
	{
    while($yrow = $eggSizeResult->fetch_assoc()) 
	{
        $eggSizeDetails[] = $yrow;
    }
}

$existingPRE2Query = "SELECT COUNT(*) FROM predata_ew WHERE ProductionDate = ?";
$existingPRE2Result = executeQuery($conn, $existingPRE2Query, "s", [date("Y-m-d")]);

if ($existingPRE2Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPRE2Count = mysqli_fetch_row($existingPRE2Result)[0];

$existingPOST2Query = "SELECT COUNT(*) FROM egg_weight WHERE ProductionDate = ?";
$existingPOST2Result = executeQuery($conn, $existingPOST2Query, "s", [date("Y-m-d")]);

if ($existingPOST2Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPOST2Count = mysqli_fetch_row($existingPOST2Result)[0];

if ($existingPRE2Count == 0 && $existingPOST2Count == 0) 
{
    try 
	{
		foreach ($eggSizeDetails as $eggDetail) {
			$eggSizeBatchName = $eggDetail["BatchName"];
			$eggSizeBatchCode = $eggDetail["BatchCode"];
			
			$AgeResult = executeQuery($conn, "SELECT FLOOR(DATEDIFF(?, CheckInDate) / 7) as AgeInWeeks FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE AND BatchName = ?", "ss", [date("Y-m-d"),$eggSizeBatchName]);
			
			if ($AgeResult === false) { 
				throw new Exception("Error executing query: " . $conn->error);
			} 
			
			$AgeRow = mysqli_fetch_assoc($AgeResult);
			$AgeInWeeks = $AgeRow["AgeInWeeks"] ?? 0;
			
			$eggSizeResult = executeQuery($conn, "INSERT INTO predata_ew (addedby_user, ProductionDate, BatchName, BatchCode, AgeInWeeks) VALUES (?, ?, ?, ?, ?)", "sssss", [$userName, date("Y-m-d"), $eggSizeBatchName, $eggSizeBatchCode, $AgeInWeeks]);
			
			if ($eggSizeResult === false) { 
				throw new Exception("Error executing query: " . $conn->error);
			} 
			
			mysqli_commit($conn);
		}
    } 
    catch (Exception $e) 
    {
        mysqli_rollback($conn);
		// Log the error message
        error_log($e->getMessage());
		// Redirect to an error page or display an error message
        //header("Location: error_page.php");
        //exit();
    }
} 

$feedDeliveryResult = executeQuery($conn, "SELECT BatchName, BldgNo FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE");

if ($feedDeliveryResult === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$feedDeliveryDetails = [];
if ($feedDeliveryResult->num_rows > 0)
	{
    while($zrow = $feedDeliveryResult->fetch_assoc()) 
	{
        $feedDeliveryDetails[] = $zrow;
    }
}

$existingPRE3Query = "SELECT COUNT(*) FROM predata_fd WHERE ProductionDate = ?";
$existingPRE3Result = executeQuery($conn, $existingPRE3Query, "s", [date("Y-m-d")]);

if ($existingPRE3Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPRE3Count = mysqli_fetch_row($existingPRE3Result)[0];

$existingPOST3Query = "SELECT COUNT(*) FROM feed_delivery WHERE ProductionDate = ?";
$existingPOST3Result = executeQuery($conn, $existingPOST3Query, "s", [date("Y-m-d")]);

if ($existingPOST3Result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

$existingPOST3Count = mysqli_fetch_row($existingPOST3Result)[0];

if ($existingPRE3Count == 0 && $existingPOST3Count == 0) {
    try {
        foreach ($feedDeliveryDetails as $feedDeliverydetail) {
            $BatchName = $feedDeliverydetail["BatchName"];
            $bldgNos = explode(",", $feedDeliverydetail["BldgNo"]);
			
			$AgeResult = executeQuery($conn, "SELECT FLOOR(DATEDIFF(?, CheckInDate) / 7) as AgeInWeeks FROM batch_details WHERE Status = 1 AND is_deleted = FALSE AND is_current = TRUE AND BatchName = ?", "ss", [date("Y-m-d"),$BatchName]);
			
			if ($AgeResult === false) { 
				throw new Exception("Error executing query: " . $conn->error);
			} 
			
			$AgeRow = mysqli_fetch_assoc($AgeResult);
			$AgeInWeeks = $AgeRow["AgeInWeeks"];
			
            foreach ($bldgNos as $bldgNo) {
				preg_match('/\[(.*?)\]/', $bldgNo, $matches);
				
				$cleanedBldgNo = preg_replace('/\[\d+\]/', '', $bldgNo);
				$cleanedBldgNo = trim($cleanedBldgNo);
				
				$FCodeResult = executeQuery($conn, "SELECT FCode FROM fcode WHERE is_deleted = FALSE AND is_current = TRUE AND BatchName = ? AND BldgNo = ?", "ss", [$BatchName, $cleanedBldgNo]);
				
				if ($FCodeResult === false) { 
					throw new Exception("Error executing query: " . $conn->error);
				} 
				
				$FCodeRow = mysqli_fetch_assoc($FCodeResult);
				$FCode = $FCodeRow["FCode"] ?? "";
				
				$feedDeliveryResult = executeQuery($conn, "INSERT INTO predata_fd (addedby_user, ProductionDate, BatchName, BldgNo, AgeInWeeks, FCode) VALUES (?, ?, ?, ?, ?, ?)", "ssssss", [$userName, date("Y-m-d"), $BatchName, $cleanedBldgNo, $AgeInWeeks, $FCode]);
				if ($feedDeliveryResult === false) { 
					throw new Exception("Error executing query: " . $conn->error);
				} 
			}
        }
        mysqli_commit($conn);
    } 
    catch (Exception $e) 
    {
        mysqli_rollback($conn);
		// Log the error message
        error_log($e->getMessage());
		// Redirect to an error page or display an error message
        //header("Location: error_page.php");
        //exit();
    }
}
?>